Documentation
¶
Index ¶
- func GetClub(clubID string) string
- func GetClubMatches(clubID string) string
- func GetClubMembers(clubID string) string
- func GetCountry(countryISO int) string
- func GetCountryClubs(countryISO int) string
- func GetCountryPlayers(countryISO int) string
- func GetDailyPuzzle() string
- func GetDailyTeamMatch(matchID int) string
- func GetDailyTeamMatchBoard(matchID int, board int) string
- func GetLeaderboard() string
- func GetLiveTeamMatch(matchID int) string
- func GetLiveTeamMatchBoard(matchID int, board int) string
- func GetPlayerGames(username string) string
- func GetPlayerGamesArchive(username string, year int, month int) string
- func GetPlayerGamesArchivePGN(username string, year int, month int) string
- func GetPlayerGamesMonthly(username string) string
- func GetPlayerGamesToMove(username string) string
- func GetPlayerMatches(username string) string
- func GetPlayerStatus(username string) string
- func GetPlayerTournaments(username string) string
- func GetRandomPuzzle() string
- func GetStreamers() string
- func GetTitledPlayers(title string) string
- func GetTournament(tournamentID string) string
- func GetTournamentRound(tournamentID string, round int) string
- func GetTournamentRoundGroup(tournamentID string, round int, group int) string
- func GetUser(username string) string
- func GetUserStats(username string) string
- type UserInfo
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetClubMatches ¶
GetClubMatches - Returns club match details
func GetClubMembers ¶
GetClubMembers - Returns details a specific club members
func GetCountry ¶
GetCountry - Returns details about specific country
func GetCountryClubs ¶
GetCountryClubs - Returns details about specific country's clubs
func GetCountryPlayers ¶
GetCountryPlayers - Returns details about specific country's players
func GetDailyPuzzle ¶
func GetDailyPuzzle() string
GetDailyPuzzle - Returns details about the daily puzzle
func GetDailyTeamMatch ¶
GetDailyTeamMatch - Returns daily team match details
func GetDailyTeamMatchBoard ¶
GetDailyTeamMatchBoard - Returns daily team match board details
func GetLeaderboard ¶
func GetLeaderboard() string
GetLeaderboard - Returns details about the chess.com leaderboard
func GetLiveTeamMatch ¶
GetLiveTeamMatch - Returns live team match details
func GetLiveTeamMatchBoard ¶
GetLiveTeamMatchBoard - Returns live team match board details
func GetPlayerGames ¶
GetPlayerGames - Return current user games
func GetPlayerGamesArchive ¶
GetPlayerArchive - Return games the player has played in a specific month
func GetPlayerGamesArchivePGN ¶
GetPlayerGamesArchivePGN (Currently broken) - Return games the player has played in a specific month
func GetPlayerGamesMonthly ¶
GetPlayerGamesMonthly - Return games the player has played in the past month
func GetPlayerGamesToMove ¶
GetPlayerGamesToMove - Return player who has to move
func GetPlayerMatches ¶
GetPlayerMatches - Returns list of team matches the player is currently registered in
func GetPlayerStatus ¶
GetPlayerStatus (Currently Broken) - Returns T/F of players online status
func GetRandomPuzzle ¶
func GetRandomPuzzle() string
GetRandomPuzzle - Returns details about a random puzzle
func GetStreamers ¶
func GetStreamers() string
GetStreamers - Returns details about chess.com streamers
func GetTitledPlayers ¶
GetTitledPlayers - Returns an array of all titled players of specific type (i.e. GM, WGM, IM, etc)
func GetTournament ¶
GetTournament - Returns tournament details
func GetTournamentRound ¶
GetTournamentRound - Returns tournament round details
func GetTournamentRoundGroup ¶
GetTournamentRoundGroup - Returns tournament round group details
func GetUserStats ¶
GetUserStats - Returns statistics about a specific user